"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _BaseText = _interopRequireDefault(require("../../blocks/BaseText"));
var React = _interopRequireWildcard(require("react"));
var _reactNative = require("react-native");
var _blocks = _interopRequireDefault(require("../../components/blocks/blocks"));
var _dynamicRenderer = _interopRequireDefault(require("../../components/dynamic-renderer/dynamic-renderer"));
var _inlinedStyles = _interopRequireDefault(require("../../components/inlined-styles"));
var _deviceSizes = require("../../constants/device-sizes");
var _target = require("../../constants/target");
var _getClassPropName = require("../../functions/get-class-prop-name");
var _getStyle = require("../../functions/get-style");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && Object.prototype.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function Columns(props) {
  var _props$columns;
  function gutterSize() {
    return typeof props.space === "number" ? props.space || 0 : 20;
  }
  function cols() {
    return props.columns || [];
  }
  function stackAt() {
    return props.stackColumnsAt || "tablet";
  }
  function getTagName(column) {
    return column.link ? props.builderLinkComponent || _BaseText.default : _reactNative.View;
  }
  function getWidth(index) {
    var _cols$index;
    return ((_cols$index = cols()[index]) === null || _cols$index === void 0 ? void 0 : _cols$index.width) || 100 / cols().length;
  }
  function getColumnCssWidth(index) {
    const width = getWidth(index);
    const subtractWidth = gutterSize() * (cols().length - 1) * (width / 100);
    return `calc(${width}% - ${subtractWidth}px)`;
  }
  function getTabletStyle({
    stackedStyle,
    desktopStyle
  }) {
    return stackAt() === "tablet" ? stackedStyle : desktopStyle;
  }
  function getMobileStyle({
    stackedStyle,
    desktopStyle
  }) {
    return stackAt() === "never" ? desktopStyle : stackedStyle;
  }
  function flexDir() {
    return props.stackColumnsAt === "never" ? "row" : props.reverseColumnsWhenStacked ? "column-reverse" : "column";
  }
  function columnsCssVars() {
    return {
      flexDirection: flexDir()
    };
  }
  function columnCssVars(index) {
    const gutter = index === 0 ? 0 : gutterSize();
    const width = getColumnCssWidth(index);
    const gutterPixels = `${gutter}px`;
    const mobileWidth = "100%";
    const mobileMarginLeft = 0;
    const marginLeftKey = "margin-left";
    const sharedStyles = {
      display: "flex",
      flexDirection: "column",
      alignItems: "stretch"
    };
    return {
      ...sharedStyles,
      marginLeft: props.stackColumnsAt === "never" ? gutter : 0
    };
  }
  function getWidthForBreakpointSize(size) {
    var _props$builderContext;
    const breakpointSizes = (0, _deviceSizes.getSizesForBreakpoints)(((_props$builderContext = props.builderContext.content) === null || _props$builderContext === void 0 || (_props$builderContext = _props$builderContext.meta) === null || _props$builderContext === void 0 ? void 0 : _props$builderContext.breakpoints) || {});
    return breakpointSizes[size].max;
  }
  function columnsStyles() {
    const childColumnDiv = `.${props.builderBlock.id}-breakpoints > .builder-column`;
    return `
        @media (max-width: ${getWidthForBreakpointSize("medium")}px) {
          .${props.builderBlock.id}-breakpoints {
            flex-direction: var(--flex-dir-tablet);
            align-items: stretch;
          }

          ${childColumnDiv} {
            width: var(--column-width-tablet) !important;
            margin-left: var(--column-margin-left-tablet) !important;
          }
        }

        @media (max-width: ${getWidthForBreakpointSize("small")}px) {
          .${props.builderBlock.id}-breakpoints {
            flex-direction: var(--flex-dir);
            align-items: stretch;
          }

          ${childColumnDiv} {
            width: var(--column-width-mobile) !important;
            margin-left: var(--column-margin-left-mobile) !important;
          }
        },
      `;
  }
  function getAttributes(column, index) {
    return {
      ...{
        dataSet: {
          "builder-block-name": "builder-column"
        }
      },
      ...(column.link ? {
        href: column.link
      } : {}),
      [(0, _getClassPropName.getClassPropName)()]: "builder-column",
      style: (0, _getStyle.mapStyleObjToStrIfNeeded)(columnCssVars(index))
    };
  }
  return /*#__PURE__*/React.createElement(_reactNative.View, {
    style: {
      ...styles.view1,
      ...columnsCssVars()
    },
    dataSet: {
      "builder-block-name": "builder-columns"
    }
  }, _target.TARGET !== "reactNative" ? /*#__PURE__*/React.createElement(_inlinedStyles.default, {
    id: "builderio-columns",
    styles: columnsStyles(),
    nonce: props.builderContext.nonce
  }) : null, (_props$columns = props.columns) === null || _props$columns === void 0 ? void 0 : _props$columns.map((column, index) => /*#__PURE__*/React.createElement(_dynamicRenderer.default, {
    key: index,
    TagName: getTagName(column),
    actionAttributes: {},
    attributes: getAttributes(column, index)
  }, /*#__PURE__*/React.createElement(_blocks.default, {
    path: `columns.${index}.blocks`,
    parent: props.builderBlock.id,
    context: props.builderContext,
    registeredComponents: props.builderComponents,
    linkComponent: props.builderLinkComponent,
    blocks: column.blocks,
    styleProp: {
      flexGrow: 1
    }
  }))));
}
const styles = _reactNative.StyleSheet.create({
  view1: {
    display: "flex",
    height: "100%"
  }
});
var _default = exports.default = Columns;
//# sourceMappingURL=columns.js.map