"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getStyle = void 0;
exports.mapStyleObjToStrIfNeeded = mapStyleObjToStrIfNeeded;
var _target = require("../constants/target");
var _css = require("../helpers/css");
var _transformStyleProperty = require("./transform-style-property");
const getStyle = ({
  block,
  context
}) => {
  return mapStyleObjToStrIfNeeded((0, _transformStyleProperty.transformStyleProperty)({
    style: block.style || {},
    context,
    block
  }));
};

/**
 * Svelte does not support style attribute as an object so we need to flatten it.
 *
 * Additionally, Svelte, Vue and other frameworks use kebab-case styles, so we need to convert them.
 */
exports.getStyle = getStyle;
function mapStyleObjToStrIfNeeded(style) {
  switch (_target.TARGET) {
    case 'svelte':
    case 'vue':
    case 'solid':
    case 'angular':
      return (0, _css.convertStyleMapToCSSArray)(style).join(' ');
    case 'qwik':
    case 'reactNative':
    case 'react':
    case 'rsc':
      return style;
  }
}
//# sourceMappingURL=get-style.js.map