import BaseText from "../../blocks/BaseText";
import * as React from "react";
import { View, StyleSheet } from "react-native";
import Blocks from "../../components/blocks/blocks";
import DynamicRenderer from "../../components/dynamic-renderer/dynamic-renderer";
import InlinedStyles from "../../components/inlined-styles";
import { getSizesForBreakpoints } from "../../constants/device-sizes";
import { TARGET } from "../../constants/target";
import { getClassPropName } from "../../functions/get-class-prop-name";
import { mapStyleObjToStrIfNeeded } from "../../functions/get-style";
function Columns(props) {
  var _props$columns;
  function gutterSize() {
    return typeof props.space === "number" ? props.space || 0 : 20;
  }
  function cols() {
    return props.columns || [];
  }
  function stackAt() {
    return props.stackColumnsAt || "tablet";
  }
  function getTagName(column) {
    return column.link ? props.builderLinkComponent || BaseText : View;
  }
  function getWidth(index) {
    var _cols$index;
    return ((_cols$index = cols()[index]) === null || _cols$index === void 0 ? void 0 : _cols$index.width) || 100 / cols().length;
  }
  function getColumnCssWidth(index) {
    const width = getWidth(index);
    const subtractWidth = gutterSize() * (cols().length - 1) * (width / 100);
    return `calc(${width}% - ${subtractWidth}px)`;
  }
  function getTabletStyle({
    stackedStyle,
    desktopStyle
  }) {
    return stackAt() === "tablet" ? stackedStyle : desktopStyle;
  }
  function getMobileStyle({
    stackedStyle,
    desktopStyle
  }) {
    return stackAt() === "never" ? desktopStyle : stackedStyle;
  }
  function flexDir() {
    return props.stackColumnsAt === "never" ? "row" : props.reverseColumnsWhenStacked ? "column-reverse" : "column";
  }
  function columnsCssVars() {
    return {
      flexDirection: flexDir()
    };
  }
  function columnCssVars(index) {
    const gutter = index === 0 ? 0 : gutterSize();
    const width = getColumnCssWidth(index);
    const gutterPixels = `${gutter}px`;
    const mobileWidth = "100%";
    const mobileMarginLeft = 0;
    const marginLeftKey = "margin-left";
    const sharedStyles = {
      display: "flex",
      flexDirection: "column",
      alignItems: "stretch"
    };
    return {
      ...sharedStyles,
      marginLeft: props.stackColumnsAt === "never" ? gutter : 0
    };
  }
  function getWidthForBreakpointSize(size) {
    var _props$builderContext;
    const breakpointSizes = getSizesForBreakpoints(((_props$builderContext = props.builderContext.content) === null || _props$builderContext === void 0 || (_props$builderContext = _props$builderContext.meta) === null || _props$builderContext === void 0 ? void 0 : _props$builderContext.breakpoints) || {});
    return breakpointSizes[size].max;
  }
  function columnsStyles() {
    const childColumnDiv = `.${props.builderBlock.id}-breakpoints > .builder-column`;
    return `
        @media (max-width: ${getWidthForBreakpointSize("medium")}px) {
          .${props.builderBlock.id}-breakpoints {
            flex-direction: var(--flex-dir-tablet);
            align-items: stretch;
          }

          ${childColumnDiv} {
            width: var(--column-width-tablet) !important;
            margin-left: var(--column-margin-left-tablet) !important;
          }
        }

        @media (max-width: ${getWidthForBreakpointSize("small")}px) {
          .${props.builderBlock.id}-breakpoints {
            flex-direction: var(--flex-dir);
            align-items: stretch;
          }

          ${childColumnDiv} {
            width: var(--column-width-mobile) !important;
            margin-left: var(--column-margin-left-mobile) !important;
          }
        },
      `;
  }
  function getAttributes(column, index) {
    return {
      ...{
        dataSet: {
          "builder-block-name": "builder-column"
        }
      },
      ...(column.link ? {
        href: column.link
      } : {}),
      [getClassPropName()]: "builder-column",
      style: mapStyleObjToStrIfNeeded(columnCssVars(index))
    };
  }
  return /*#__PURE__*/React.createElement(View, {
    style: {
      ...styles.view1,
      ...columnsCssVars()
    },
    dataSet: {
      "builder-block-name": "builder-columns"
    }
  }, TARGET !== "reactNative" ? /*#__PURE__*/React.createElement(InlinedStyles, {
    id: "builderio-columns",
    styles: columnsStyles(),
    nonce: props.builderContext.nonce
  }) : null, (_props$columns = props.columns) === null || _props$columns === void 0 ? void 0 : _props$columns.map((column, index) => /*#__PURE__*/React.createElement(DynamicRenderer, {
    key: index,
    TagName: getTagName(column),
    actionAttributes: {},
    attributes: getAttributes(column, index)
  }, /*#__PURE__*/React.createElement(Blocks, {
    path: `columns.${index}.blocks`,
    parent: props.builderBlock.id,
    context: props.builderContext,
    registeredComponents: props.builderComponents,
    linkComponent: props.builderLinkComponent,
    blocks: column.blocks,
    styleProp: {
      flexGrow: 1
    }
  }))));
}
const styles = StyleSheet.create({
  view1: {
    display: "flex",
    height: "100%"
  }
});
export default Columns;
//# sourceMappingURL=columns.js.map