function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
import * as React from "react";
import { ScrollView } from "react-native";
import { useState, useRef, useEffect } from "react";
import builderContext from "../../../context/builder.context";
import { evaluate } from "../../../functions/evaluate/index";
import { fastClone } from "../../../functions/fast-clone";
import { fetchOneEntry } from "../../../functions/get-content/index";
import { isBrowser } from "../../../functions/is-browser";
import { isEditing } from "../../../functions/is-editing";
import { isPreviewing } from "../../../functions/is-previewing";
import { logFetch } from "../../../functions/log-fetch";
import { createRegisterComponentMessage } from "../../../functions/register-component";
import { _track } from "../../../functions/track/index";
import { getInteractionPropertiesForEvent } from "../../../functions/track/interaction";
import { getDefaultCanTrack } from "../../../helpers/canTrack";
import { getCookieSync } from "../../../helpers/cookie";
import { createEditorListener } from "../../../helpers/subscribe-to-editor";
import { setupBrowserForEditing } from "../../../scripts/init-editing";
import { triggerAnimation } from "../../block/animator";
import { needsElementRefDivForEditing } from "./enable-editor.helpers";
function EnableEditor(props) {
  var _props$builderContext13;
  const elementRef = useRef(null);
  const [hasExecuted, setHasExecuted] = useState(() => false);
  function mergeNewRootState(newData) {
    const combinedState = {
      ...props.builderContextSignal.rootState,
      ...newData
    };
    if (props.builderContextSignal.rootSetState) {
      var _props$builderContext, _props$builderContext2;
      (_props$builderContext = (_props$builderContext2 = props.builderContextSignal).rootSetState) === null || _props$builderContext === void 0 || _props$builderContext.call(_props$builderContext2, combinedState);
    } else {
      props.setBuilderContextSignal(PREVIOUS_VALUE => ({
        ...PREVIOUS_VALUE,
        rootState: combinedState
      }));
    }
  }
  function mergeNewContent(newContent) {
    var _props$builderContext3, _props$builderContext4, _newContent$meta, _props$builderContext5;
    const newContentValue = {
      ...props.builderContextSignal.content,
      ...newContent,
      data: {
        ...((_props$builderContext3 = props.builderContextSignal.content) === null || _props$builderContext3 === void 0 ? void 0 : _props$builderContext3.data),
        ...(newContent === null || newContent === void 0 ? void 0 : newContent.data)
      },
      meta: {
        ...((_props$builderContext4 = props.builderContextSignal.content) === null || _props$builderContext4 === void 0 ? void 0 : _props$builderContext4.meta),
        ...(newContent === null || newContent === void 0 ? void 0 : newContent.meta),
        breakpoints: (newContent === null || newContent === void 0 || (_newContent$meta = newContent.meta) === null || _newContent$meta === void 0 ? void 0 : _newContent$meta.breakpoints) || ((_props$builderContext5 = props.builderContextSignal.content) === null || _props$builderContext5 === void 0 || (_props$builderContext5 = _props$builderContext5.meta) === null || _props$builderContext5 === void 0 ? void 0 : _props$builderContext5.breakpoints)
      }
    };
    props.setBuilderContextSignal(PREVIOUS_VALUE => ({
      ...PREVIOUS_VALUE,
      content: newContentValue
    }));
  }
  function showContentProps() {
    return props.showContent ? {} : {
      hidden: true,
      "aria-hidden": true
    };
  }
  const [ContentWrapper, setContentWrapper] = useState(() => props.contentWrapper || ScrollView);
  function processMessage(event) {
    return createEditorListener({
      model: props.model,
      trustedHosts: props.trustedHosts,
      callbacks: {
        configureSdk: messageContent => {
          var _props$builderContext6;
          const {
            breakpoints,
            contentId
          } = messageContent;
          if (!contentId || contentId !== ((_props$builderContext6 = props.builderContextSignal.content) === null || _props$builderContext6 === void 0 ? void 0 : _props$builderContext6.id)) {
            return;
          }
          if (breakpoints) {
            mergeNewContent({
              meta: {
                breakpoints
              }
            });
          }
        },
        animation: animation => {
          triggerAnimation(animation);
        },
        contentUpdate: newContent => {
          mergeNewContent(newContent);
        },
        stateUpdate: newState => {
          mergeNewRootState(newState);
        }
      }
    })(event);
  }
  const [httpReqsData, setHttpReqsData] = useState(() => ({}));
  const [httpReqsPending, setHttpReqsPending] = useState(() => ({}));
  const [clicked, setClicked] = useState(() => false);
  function onClick(event) {
    if (props.builderContextSignal.content) {
      var _props$builderContext7, _props$builderContext8;
      const variationId = (_props$builderContext7 = props.builderContextSignal.content) === null || _props$builderContext7 === void 0 ? void 0 : _props$builderContext7.testVariationId;
      const contentId = (_props$builderContext8 = props.builderContextSignal.content) === null || _props$builderContext8 === void 0 ? void 0 : _props$builderContext8.id;
      _track({
        apiHost: props.apiHost,
        type: "click",
        canTrack: getDefaultCanTrack(props.canTrack),
        contentId,
        apiKey: props.apiKey,
        variationId: variationId !== contentId ? variationId : undefined,
        ...getInteractionPropertiesForEvent(event),
        unique: !clicked
      });
    }
    if (!clicked) {
      setClicked(true);
    }
  }
  function runHttpRequests() {
    var _props$builderContext9;
    const requests = ((_props$builderContext9 = props.builderContextSignal.content) === null || _props$builderContext9 === void 0 || (_props$builderContext9 = _props$builderContext9.data) === null || _props$builderContext9 === void 0 ? void 0 : _props$builderContext9.httpRequests) ?? {};
    Object.entries(requests).forEach(([key, httpRequest]) => {
      if (!httpRequest) return;
      const isCoreRequest = typeof httpRequest === "object" && httpRequest["@type"] === "@builder.io/core:Request";

      // request already in progress
      if (httpReqsPending[key]) return;

      // request already completed, and not in edit mode
      if (httpReqsData[key] && !isEditing()) return;
      const url = isCoreRequest ? httpRequest.request.url : httpRequest;
      httpReqsPending[key] = true;
      const evaluatedUrl = url.replace(/{{([^}]+)}}/g, (_match, group) => String(evaluate({
        code: group,
        context: props.context || {},
        localState: undefined,
        rootState: props.builderContextSignal.rootState,
        rootSetState: props.builderContextSignal.rootSetState
      })));
      const fetchRequestObj = isCoreRequest ? {
        url: evaluatedUrl,
        method: httpRequest.request.method,
        headers: httpRequest.request.headers,
        body: httpRequest.request.body
      } : {
        url: evaluatedUrl,
        method: "GET"
      };
      logFetch(JSON.stringify(fetchRequestObj));
      fetch(fetchRequestObj.url, {
        method: fetchRequestObj.method,
        headers: fetchRequestObj.headers,
        body: fetchRequestObj.body
      }).then(response => response.json()).then(json => {
        mergeNewRootState({
          [key]: json
        });
        httpReqsData[key] = true;
      }).catch(err => {
        console.error("error fetching dynamic data", JSON.stringify(httpRequest), err);
      }).finally(() => {
        httpReqsPending[key] = false;
      });
    });
  }
  function emitStateUpdate() {
    if (isEditing()) {
      window.dispatchEvent(new CustomEvent("builder:component:stateChange", {
        detail: {
          state: fastClone(props.builderContextSignal.rootState),
          ref: {
            name: props.model
          }
        }
      }));
    }
  }
  function elementRef_onIniteditingbldr(event) {
    window.addEventListener("message", processMessage);
    setupBrowserForEditing({
      ...(props.locale ? {
        locale: props.locale
      } : {}),
      ...(props.enrich ? {
        enrich: props.enrich
      } : {}),
      ...(props.trustedHosts ? {
        trustedHosts: props.trustedHosts
      } : {}),
      modelName: props.model ?? "",
      apiKey: props.apiKey
    });
    Object.values(props.builderContextSignal.componentInfos).forEach(registeredComponent => {
      var _registeredComponent$;
      if (!((_registeredComponent$ = registeredComponent.models) !== null && _registeredComponent$ !== void 0 && _registeredComponent$.length) || registeredComponent.models.includes(props.model)) {
        var _window$parent;
        const message = createRegisterComponentMessage(registeredComponent);
        (_window$parent = window.parent) === null || _window$parent === void 0 || _window$parent.postMessage(message, "*");
      }
    });
    window.addEventListener("builder:component:stateChangeListenerActivated", emitStateUpdate);
  }
  function elementRef_onInitpreviewingbldr(event) {
    const searchParams = new URL(location.href).searchParams;
    const searchParamPreviewModel = searchParams.get("builder.preview");
    const searchParamPreviewId = searchParams.get(`builder.overrides.${searchParamPreviewModel}`);
    const previewApiKey = searchParams.get("apiKey") || searchParams.get("builder.space");

    /**
     * Make sure that:
     * - the preview model name is the same as the one we're rendering, since there can be multiple models rendered *  at the same time, e.g. header/page/footer. * - the API key is the same, since we don't want to preview content from other organizations.
     * - if there is content, that the preview ID is the same as that of the one we receive.
     *
     * TO-DO: should we only update the state when there is a change?
     **/
    if (searchParamPreviewModel === "BUILDER_STUDIO" || searchParamPreviewModel === props.model && previewApiKey === props.apiKey && (!props.content || searchParamPreviewId === props.content.id)) {
      var _props$context;
      fetchOneEntry({
        model: props.model,
        apiKey: props.apiKey,
        apiVersion: props.builderContextSignal.apiVersion,
        ...(searchParamPreviewModel === "BUILDER_STUDIO" && (_props$context = props.context) !== null && _props$context !== void 0 && _props$context.symbolId ? {
          query: {
            id: props.context.symbolId
          }
        } : {})
      }).then(content => {
        if (content) {
          mergeNewContent(content);
        }
      });
    }
  }
  const hasInitialized = useRef(false);
  if (!hasInitialized.current) {
    runHttpRequests();
    emitStateUpdate();
    hasInitialized.current = true;
  }
  useEffect(() => {
    if (isBrowser()) {
      var _props$builderContext10, _props$builderContext11;
      if (isEditing() && !props.isNestedRender) {
        window.addEventListener("message", processMessage);
        setupBrowserForEditing({
          ...(props.locale ? {
            locale: props.locale
          } : {}),
          ...(props.enrich ? {
            enrich: props.enrich
          } : {}),
          ...(props.trustedHosts ? {
            trustedHosts: props.trustedHosts
          } : {}),
          modelName: props.model ?? "",
          apiKey: props.apiKey
        });
        Object.values(props.builderContextSignal.componentInfos).forEach(registeredComponent => {
          var _registeredComponent$2;
          if (!((_registeredComponent$2 = registeredComponent.models) !== null && _registeredComponent$2 !== void 0 && _registeredComponent$2.length) || registeredComponent.models.includes(props.model)) {
            var _window$parent2;
            const message = createRegisterComponentMessage(registeredComponent);
            (_window$parent2 = window.parent) === null || _window$parent2 === void 0 || _window$parent2.postMessage(message, "*");
          }
        });
        window.addEventListener("builder:component:stateChangeListenerActivated", emitStateUpdate);
      }
      const shouldTrackImpression = props.builderContextSignal.content && getDefaultCanTrack(props.canTrack);
      const winningVariantId = getCookieSync({
        name: `builder.tests.${(_props$builderContext10 = props.builderContextSignal.content) === null || _props$builderContext10 === void 0 ? void 0 : _props$builderContext10.id}`,
        canTrack: true
      });
      const variationId = (_props$builderContext11 = props.builderContextSignal.content) === null || _props$builderContext11 === void 0 ? void 0 : _props$builderContext11.testVariationId;
      if (shouldTrackImpression && variationId === winningVariantId) {
        var _props$builderContext12;
        const contentId = (_props$builderContext12 = props.builderContextSignal.content) === null || _props$builderContext12 === void 0 ? void 0 : _props$builderContext12.id;
        const apiKeyProp = props.apiKey;
        _track({
          apiHost: props.apiHost,
          type: "impression",
          canTrack: true,
          contentId,
          apiKey: apiKeyProp,
          variationId: winningVariantId !== contentId ? winningVariantId : undefined
        });
      }

      /**
       * Override normal content in preview mode.
       * We ignore this when editing, since the edited content is already being sent from the editor via post messages.
       */
      if (isPreviewing() && !isEditing()) {
        const searchParams = new URL(location.href).searchParams;
        const searchParamPreviewModel = searchParams.get("builder.preview");
        const searchParamPreviewId = searchParams.get(`builder.overrides.${searchParamPreviewModel}`);
        const previewApiKey = searchParams.get("apiKey") || searchParams.get("builder.space");

        /**
         * Make sure that:
         * - the preview model name is the same as the one we're rendering, since there can be multiple models rendered   *  at the same time, e.g. header/page/footer.   * - the API key is the same, since we don't want to preview content from other organizations.
         * - if there is content, that the preview ID is the same as that of the one we receive.
         *
         * TO-DO: should we only update the state when there is a change?
         **/
        if (searchParamPreviewModel === "BUILDER_STUDIO" || searchParamPreviewModel === props.model && previewApiKey === props.apiKey && (!props.content || searchParamPreviewId === props.content.id)) {
          var _props$context2;
          fetchOneEntry({
            model: props.model,
            apiKey: props.apiKey,
            apiVersion: props.builderContextSignal.apiVersion,
            ...(searchParamPreviewModel === "BUILDER_STUDIO" && (_props$context2 = props.context) !== null && _props$context2 !== void 0 && _props$context2.symbolId ? {
              query: {
                id: props.context.symbolId
              }
            } : {})
          }).then(content => {
            if (content) {
              mergeNewContent(content);
            }
          });
        }
      }
    }
  }, []);
  useEffect(() => {
    if (props.content) {
      mergeNewContent(props.content);
    }
  }, [props.content]);
  useEffect(() => {
    emitStateUpdate();
  }, [props.builderContextSignal.rootState]);
  useEffect(() => {
    if (props.data) {
      mergeNewRootState(props.data);
    }
  }, [props.data]);
  useEffect(() => {
    if (props.locale) {
      mergeNewRootState({
        locale: props.locale
      });
    }
  }, [props.locale]);
  useEffect(() => {
    return () => {
      if (isBrowser()) {
        window.removeEventListener("message", processMessage);
        window.removeEventListener("builder:component:stateChangeListenerActivated", emitStateUpdate);
      }
    };
  }, []);
  return /*#__PURE__*/React.createElement(builderContext.Provider, {
    value: props.builderContextSignal
  }, props.builderContextSignal.content || needsElementRefDivForEditing() ? /*#__PURE__*/React.createElement(ContentWrapper, _extends({
    ref: elementRef,
    onClick: event => onClick(event),
    "builder-content-id": (_props$builderContext13 = props.builderContextSignal.content) === null || _props$builderContext13 === void 0 ? void 0 : _props$builderContext13.id,
    "builder-model": props.model,
    style: {
      display: !props.builderContextSignal.content && needsElementRefDivForEditing() ? "none" : undefined
    },
    // currently, we can't set the actual ID here. // we don't need it right now, we just need to identify content divs for testing.
    dataSet: {
      "builder-content-id": ""
    }
  }, showContentProps(), props.contentWrapperProps), props.children) : null);
}
export default EnableEditor;
//# sourceMappingURL=enable-editor.js.map