import * as React from "react";
import { ScrollView } from "react-native";
import { useState, useRef } from "react";
import { getDefaultRegisteredComponents } from "../../constants/builder-registered-components";
import { TARGET } from "../../constants/target";
import ComponentsContext from "../../context/components.context";
import { evaluate } from "../../functions/evaluate/evaluate";
import { serializeIncludingFunctions } from "../../functions/register-component";
import { logger } from "../../helpers/logger";
import Blocks from "../blocks/blocks";
import { getUpdateVariantVisibilityScript } from "../content-variants/helpers";
import InlinedScript from "../inlined-script";
import EnableEditor from "./components/enable-editor";
import ContentStyles from "./components/styles";
import { getContentInitialValue, getRootStateInitialValue } from "./content.helpers";
function ContentComponent(props) {
  var _builderContextSignal2, _builderContextSignal3, _builderContextSignal4, _builderContextSignal5;
  const [scriptStr, setScriptStr] = useState(() => {
    var _props$content, _props$content2;
    return getUpdateVariantVisibilityScript({
      // eslint-disable-next-line @typescript-eslint/no-non-null-assertion, @typescript-eslint/no-non-null-asserted-optional-chain
      variationId: (_props$content = props.content) === null || _props$content === void 0 ? void 0 : _props$content.testVariationId,
      // eslint-disable-next-line @typescript-eslint/no-non-null-assertion, @typescript-eslint/no-non-null-asserted-optional-chain
      contentId: (_props$content2 = props.content) === null || _props$content2 === void 0 ? void 0 : _props$content2.id
    });
  });
  function contentSetState(newRootState) {
    setBuilderContextSignal(PREVIOUS_VALUE => ({
      ...PREVIOUS_VALUE,
      rootState: newRootState
    }));
  }
  const [registeredComponents, setRegisteredComponents] = useState(() => [...getDefaultRegisteredComponents(), ...(props.customComponents || [])].reduce((acc, {
    component,
    ...info
  }) => ({
    ...acc,
    [info.name]: {
      component: component,
      ...serializeIncludingFunctions(info)
    }
  }), {}));
  const [builderContextSignal, setBuilderContextSignal] = useState(() => ({
    strictStyleMode: props.strictStyleMode,
    content: getContentInitialValue({
      content: props.content,
      data: props.data
    }),
    localState: undefined,
    rootState: getRootStateInitialValue({
      content: props.content,
      data: props.data,
      locale: props.locale
    }),
    rootSetState: contentSetState,
    context: props.context || {},
    canTrack: props.canTrack,
    apiKey: props.apiKey,
    apiVersion: props.apiVersion,
    componentInfos: [...getDefaultRegisteredComponents(), ...(props.customComponents || [])].reduce((acc, {
      component: _,
      ...info
    }) => ({
      ...acc,
      [info.name]: serializeIncludingFunctions(info)
    }), {}),
    inheritedStyles: {},
    BlocksWrapper: props.blocksWrapper || ScrollView,
    BlocksWrapperProps: props.blocksWrapperProps || {},
    nonce: props.nonce || "",
    model: props.model
  }));
  const hasInitialized = useRef(false);
  if (!hasInitialized.current) {
    var _builderContextSignal;
    if (!props.apiKey) {
      logger.error("No API key provided to `Content` component. This can cause issues. Please provide an API key using the `apiKey` prop.");
    }

    // run any dynamic JS code attached to content
    const jsCode = (_builderContextSignal = builderContextSignal.content) === null || _builderContextSignal === void 0 || (_builderContextSignal = _builderContextSignal.data) === null || _builderContextSignal === void 0 ? void 0 : _builderContextSignal.jsCode;
    if (jsCode) {
      evaluate({
        code: jsCode,
        context: props.context || {},
        localState: undefined,
        rootState: builderContextSignal.rootState,
        rootSetState: newState => {
          setBuilderContextSignal(PREVIOUS_VALUE => ({
            ...PREVIOUS_VALUE,
            rootState: newState
          }));
        },
        isExpression: false
      });
    }
    hasInitialized.current = true;
  }
  return /*#__PURE__*/React.createElement(ComponentsContext.Provider, {
    value: {
      registeredComponents: registeredComponents
    }
  }, /*#__PURE__*/React.createElement(EnableEditor, {
    apiHost: props.apiHost,
    nonce: props.nonce,
    content: props.content,
    data: props.data,
    model: props.model,
    context: props.context,
    apiKey: props.apiKey,
    canTrack: props.canTrack,
    locale: props.locale,
    enrich: props.enrich,
    showContent: props.showContent,
    builderContextSignal: builderContextSignal,
    contentWrapper: props.contentWrapper,
    contentWrapperProps: props.contentWrapperProps,
    trustedHosts: props.trustedHosts,
    isNestedRender: props.isNestedRender,
    // eslint-disable-next-line object-shorthand
    setBuilderContextSignal: setBuilderContextSignal,
    // eslint-disable-next-line @typescript-eslint/ban-ts-comment
    // @ts-ignore
    strictStyleMode: props.strictStyleMode
  }, props.isSsrAbTest ? /*#__PURE__*/React.createElement(InlinedScript, {
    id: "builderio-variant-visibility",
    scriptStr: scriptStr,
    nonce: props.nonce || ""
  }) : null, TARGET !== "reactNative" ? /*#__PURE__*/React.createElement(ContentStyles, {
    nonce: props.nonce || "",
    isNestedRender: props.isNestedRender,
    contentId: (_builderContextSignal2 = builderContextSignal.content) === null || _builderContextSignal2 === void 0 ? void 0 : _builderContextSignal2.id,
    cssCode: (_builderContextSignal3 = builderContextSignal.content) === null || _builderContextSignal3 === void 0 || (_builderContextSignal3 = _builderContextSignal3.data) === null || _builderContextSignal3 === void 0 ? void 0 : _builderContextSignal3.cssCode,
    customFonts: (_builderContextSignal4 = builderContextSignal.content) === null || _builderContextSignal4 === void 0 || (_builderContextSignal4 = _builderContextSignal4.data) === null || _builderContextSignal4 === void 0 ? void 0 : _builderContextSignal4.customFonts
  }) : null, /*#__PURE__*/React.createElement(Blocks, {
    blocks: (_builderContextSignal5 = builderContextSignal.content) === null || _builderContextSignal5 === void 0 || (_builderContextSignal5 = _builderContextSignal5.data) === null || _builderContextSignal5 === void 0 ? void 0 : _builderContextSignal5.blocks,
    context: builderContextSignal,
    registeredComponents: registeredComponents,
    linkComponent: props.linkComponent
  })));
}
export default ContentComponent;
//# sourceMappingURL=content.js.map