import { logger } from "../../helpers/logger";
import { get } from "../get";
import { chooseBrowserOrServerEval } from "./choose-eval";
import { getBuilderGlobals, parseCode } from "./helpers";
/**
 * handles multi-level gets on state: `state.x.y.z`
 * does not handle bracket notation
 * see https://regexr.com/87a9j
 */
const STATE_GETTER_REGEX = /^(return )?(\s*)?state(?<getPath>(\.\w+)+)(\s*);?$/;

/**
 * Handles multi-level gets on state transpiled by rollup with virtual index.
 * see https://regexr.com/87ai4
 */
const VIRTUAL_INDEX_REGEX = /(\s)*var(\s)+_virtual_index(\s)*=(\s)*state(?<getPath>(\.\w+)+)(\s*);?(\s)*return(\s)*_virtual_index(\s)*/;
export const getSimpleExpressionGetPath = code => {
  var _STATE_GETTER_REGEX$e, _VIRTUAL_INDEX_REGEX$;
  return ((_STATE_GETTER_REGEX$e = STATE_GETTER_REGEX.exec(code.trim())) === null || _STATE_GETTER_REGEX$e === void 0 || (_STATE_GETTER_REGEX$e = _STATE_GETTER_REGEX$e.groups) === null || _STATE_GETTER_REGEX$e === void 0 || (_STATE_GETTER_REGEX$e = _STATE_GETTER_REGEX$e.getPath) === null || _STATE_GETTER_REGEX$e === void 0 ? void 0 : _STATE_GETTER_REGEX$e.slice(1)) || ((_VIRTUAL_INDEX_REGEX$ = VIRTUAL_INDEX_REGEX.exec(code.trim())) === null || _VIRTUAL_INDEX_REGEX$ === void 0 || (_VIRTUAL_INDEX_REGEX$ = _VIRTUAL_INDEX_REGEX$.groups) === null || _VIRTUAL_INDEX_REGEX$ === void 0 || (_VIRTUAL_INDEX_REGEX$ = _VIRTUAL_INDEX_REGEX$.getPath) === null || _VIRTUAL_INDEX_REGEX$ === void 0 ? void 0 : _VIRTUAL_INDEX_REGEX$.slice(1));
};
export function evaluate({
  code,
  context,
  localState,
  rootState,
  rootSetState,
  event,
  isExpression = true
}) {
  if (code.trim() === '') {
    return undefined;
  }

  /**
   * For very simple expressions like "state.foo" we can optimize by skipping
   * the executor altogether.
   * We try not to take many risks with this optimizations, so we only do it for
   * `state.{path}` expressions.
   */
  const getPath = getSimpleExpressionGetPath(code.trim());
  if (getPath) {
    return get({
      ...rootState,
      ...localState
    }, getPath);
  }
  const args = {
    code: parseCode(code, {
      isExpression
    }),
    builder: getBuilderGlobals(),
    context,
    event,
    rootSetState,
    rootState,
    localState
  };
  try {
    const newEval = chooseBrowserOrServerEval(args);
    return newEval;
  } catch (e) {
    logger.error('Failed code evaluation: ' + e.message, {
      code
    });
    return undefined;
  }
}
//# sourceMappingURL=evaluate.js.map