"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.flattenState = flattenState;
exports.parseCode = exports.getFunctionArguments = exports.getBuilderGlobals = void 0;
var _isBrowser = require("../is-browser");
var _isEditing = require("../is-editing");
var _helpers = require("../track/helpers");
const getFunctionArguments = ({
  builder,
  context,
  event,
  state
}) => {
  return Object.entries({
    state,
    Builder: builder,
    // legacy
    builder,
    context,
    event
  });
};
exports.getFunctionArguments = getFunctionArguments;
const getBuilderGlobals = () => ({
  isEditing: (0, _isEditing.isEditing)(),
  isBrowser: (0, _isBrowser.isBrowser)(),
  isServer: !(0, _isBrowser.isBrowser)(),
  getUserAttributes: () => (0, _helpers.getUserAttributes)()
});
exports.getBuilderGlobals = getBuilderGlobals;
const parseCode = (code, {
  isExpression = true
}) => {
  // Be able to handle simple expressions like "state.foo" or "1 + 1"
  // as well as full blocks like "var foo = "bar"; return foo"
  const useReturn =
  // we disable this for cases where we definitely don't want a return
  isExpression && !(code.includes(';') || code.includes(' return ') || code.trim().startsWith('return '));
  const useCode = useReturn ? `return (${code});` : code;
  return useCode;
};
exports.parseCode = parseCode;
function flattenState({
  rootState,
  localState,
  rootSetState
}) {
  return new Proxy(rootState, {
    get: (target, prop) => {
      if (localState && prop in localState) {
        return localState[prop];
      }
      const val = target[prop];
      if (typeof val === 'object' && val !== null) {
        return flattenState({
          rootState: val,
          localState: undefined,
          rootSetState: rootSetState ? subState => {
            target[prop] = subState;
            rootSetState(target);
          } : undefined
        });
      }
      return val;
    },
    set: (target, prop, value) => {
      if (localState && prop in localState) {
        throw new Error('Writing to local state is not allowed as it is read-only.');
      }
      target[prop] = value;
      rootSetState === null || rootSetState === void 0 || rootSetState(target);
      return true;
    }
  });
}
//# sourceMappingURL=helpers.js.map