"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.deepCloneWithConditions = deepCloneWithConditions;
exports.getProcessedBlock = getProcessedBlock;
var _target = require("../constants/target");
var _omit = require("../helpers/omit");
var _index = require("./evaluate/index");
var _extractLocalizedValues = require("./extract-localized-values");
var _fastClone = require("./fast-clone");
var _set = require("./set");
var _transformBlock = require("./transform-block");
// Deep clone a block but without cloning any child blocks
function deepCloneWithConditions(obj) {
  if (obj === null || typeof obj !== 'object') {
    return obj;
  }
  if (Array.isArray(obj)) {
    return obj.map(item => deepCloneWithConditions(item));
  }
  if (obj['@type'] === '@builder.io/sdk:Element') {
    return obj;
  }
  const clonedObj = {};
  for (const key in obj) {
    if (key !== 'meta' && Object.prototype.hasOwnProperty.call(obj, key)) {
      clonedObj[key] = deepCloneWithConditions(obj[key]);
    }
  }
  return clonedObj;
}
const IS_SDK_WITHOUT_CACHED_PROCESSED_BLOCK = ['svelte', 'vue', 'angular', 'qwik', 'solid'].includes(_target.TARGET);
const getCopy = block => {
  if (IS_SDK_WITHOUT_CACHED_PROCESSED_BLOCK) {
    const copy = (0, _fastClone.fastClone)(block);
    const copied = {
      ...copy,
      properties: {
        ...copy.properties
      },
      actions: {
        ...copy.actions
      }
    };
    return copied;
  } else {
    const copy = deepCloneWithConditions((0, _omit.omit)(block, 'children', 'meta'));
    return {
      ...copy,
      properties: {
        ...copy.properties
      },
      actions: {
        ...copy.actions
      },
      children: block.children,
      meta: block.meta
    };
  }
};
const evaluateBindings = ({
  block,
  context,
  localState,
  rootState,
  rootSetState
}) => {
  if (!block.bindings) {
    return block;
  }
  const copied = getCopy(block);
  for (const binding in block.bindings) {
    const expression = block.bindings[binding];
    const value = (0, _index.evaluate)({
      code: expression,
      localState,
      rootState,
      rootSetState,
      context
    });
    (0, _set.set)(copied, binding, value);
  }
  return copied;
};
function getProcessedBlock({
  block,
  context,
  localState,
  rootState,
  rootSetState
}) {
  let transformedBlock = (0, _transformBlock.transformBlock)(block);
  transformedBlock = evaluateBindings({
    block: transformedBlock,
    localState,
    rootState,
    rootSetState,
    context
  });
  transformedBlock = (0, _extractLocalizedValues.resolveLocalizedValues)(transformedBlock, rootState.locale);
  return transformedBlock;
}
//# sourceMappingURL=get-processed-block.js.map