"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports._track = _track;
exports.track = void 0;
var _target = require("../../constants/target");
var _logger = require("../../helpers/logger");
var _sdkHeaders = require("../../helpers/sdk-headers");
var _sessionId = require("../../helpers/sessionId");
var _visitorId = require("../../helpers/visitorId");
var _isBrowser = require("../is-browser");
var _isEditing = require("../is-editing");
var _logFetch = require("../log-fetch");
var _helpers = require("./helpers");
const getTrackingEventData = async ({
  canTrack
}) => {
  if (!canTrack) {
    return {
      visitorId: undefined,
      sessionId: undefined
    };
  }
  const sessionId = await (0, _sessionId.getSessionId)({
    canTrack
  });
  const visitorId = (0, _visitorId.getVisitorId)({
    canTrack
  });
  return {
    sessionId,
    visitorId
  };
};
const createEvent = async ({
  type: eventType,
  canTrack,
  apiKey,
  metadata,
  ...properties
}) => ({
  type: eventType,
  data: {
    ...properties,
    metadata: {
      url: location.href,
      ...metadata
    },
    ...(await getTrackingEventData({
      canTrack
    })),
    userAttributes: (0, _helpers.getUserAttributes)(),
    ownerId: apiKey
  }
});
async function _track({
  apiHost,
  ...eventProps
}) {
  if (!eventProps.apiKey) {
    _logger.logger.error('Missing API key for track call. Please provide your API key.');
    return;
  }
  if (!eventProps.canTrack) {
    return;
  }
  if ((0, _isEditing.isEditing)()) {
    return;
  }
  if (!((0, _isBrowser.isBrowser)() || _target.TARGET === 'reactNative')) {
    return;
  }
  const baseUrl = apiHost || 'https://cdn.builder.io';
  const url = `${baseUrl}/api/v1/track`;
  (0, _logFetch.logFetch)(url);
  return fetch(url, {
    method: 'POST',
    body: JSON.stringify({
      events: [await createEvent(eventProps)]
    }),
    headers: {
      'content-type': 'application/json',
      ...(0, _sdkHeaders.getSdkHeaders)()
    },
    mode: 'cors'
  }).catch(err => {
    console.error('Failed to track: ', err);
  });
}
const track = args => _track({
  ...args,
  canTrack: true
});
exports.track = track;
//# sourceMappingURL=index.js.map