"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.setupBrowserForEditing = void 0;
var _sdkVersion = require("../constants/sdk-version");
var _target = require("../constants/target");
var _isBrowser = require("../functions/is-browser");
var _isFromTrustedHost = require("../functions/is-from-trusted-host");
let isSetupForEditing = false;
const setupBrowserForEditing = options => {
  if (isSetupForEditing) {
    return;
  }
  isSetupForEditing = true;
  if ((0, _isBrowser.isBrowser)()) {
    var _window$parent, _window$parent2;
    (_window$parent = window.parent) === null || _window$parent === void 0 || _window$parent.postMessage({
      type: 'builder.sdkInfo',
      data: {
        target: _target.TARGET,
        version: _sdkVersion.SDK_VERSION,
        supportsPatchUpdates: false,
        // Supports builder-model="..." attribute which is needed to
        // scope our '+ add block' button styling
        supportsAddBlockScoping: true,
        supportsCustomBreakpoints: true,
        modelName: options.modelName,
        apiKey: options.apiKey,
        supportsXSmallBreakpoint: _target.TARGET === 'reactNative' ? false : true,
        blockLevelPersonalization: true
      }
    }, '*');
    (_window$parent2 = window.parent) === null || _window$parent2 === void 0 || _window$parent2.postMessage({
      type: 'builder.updateContent',
      data: {
        options
      }
    }, '*');
    window.addEventListener('message', event => {
      if (!(0, _isFromTrustedHost.isFromTrustedHost)(options.trustedHosts, event)) {
        return;
      }
      const {
        data
      } = event;
      if (!(data !== null && data !== void 0 && data.type)) {
        return;
      }
      switch (data.type) {
        case 'builder.evaluate':
          {
            const text = data.data.text;
            const args = data.data.arguments || [];
            const id = data.data.id;
            // tslint:disable-next-line:no-function-constructor-with-string-args
            const fn = new Function(text);
            let result;
            let error = null;
            try {
              // eslint-disable-next-line prefer-spread
              result = fn.apply(null, args);
            } catch (err) {
              error = err;
            }
            if (error) {
              var _window$parent3;
              (_window$parent3 = window.parent) === null || _window$parent3 === void 0 || _window$parent3.postMessage({
                type: 'builder.evaluateError',
                data: {
                  id,
                  error: error.message
                }
              }, '*');
            } else {
              if (result && typeof result.then === 'function') {
                result.then(finalResult => {
                  var _window$parent4;
                  (_window$parent4 = window.parent) === null || _window$parent4 === void 0 || _window$parent4.postMessage({
                    type: 'builder.evaluateResult',
                    data: {
                      id,
                      result: finalResult
                    }
                  }, '*');
                }).catch(console.error);
              } else {
                var _window$parent5;
                (_window$parent5 = window.parent) === null || _window$parent5 === void 0 || _window$parent5.postMessage({
                  type: 'builder.evaluateResult',
                  data: {
                    result,
                    id
                  }
                }, '*');
              }
            }
            break;
          }
      }
    });
  }
};
exports.setupBrowserForEditing = setupBrowserForEditing;
//# sourceMappingURL=init-editing.js.map