import { TARGET } from "../constants/target";
import { convertStyleMapToCSSArray } from "../helpers/css";
import { transformStyleProperty } from "./transform-style-property";
export const getStyle = ({
  block,
  context
}) => {
  return mapStyleObjToStrIfNeeded(transformStyleProperty({
    style: block.style || {},
    context,
    block
  }));
};

/**
 * Svelte does not support style attribute as an object so we need to flatten it.
 *
 * Additionally, Svelte, Vue and other frameworks use kebab-case styles, so we need to convert them.
 */
export function mapStyleObjToStrIfNeeded(style) {
  switch (TARGET) {
    case 'svelte':
    case 'vue':
    case 'solid':
    case 'angular':
      return convertStyleMapToCSSArray(style).join(' ');
    case 'qwik':
    case 'reactNative':
    case 'react':
    case 'rsc':
      return style;
  }
}
//# sourceMappingURL=get-style.js.map