// polyfill `regenerator-runtime` for `react-native-storage`
import 'regenerator-runtime/runtime';
import AsyncStorage from '@react-native-async-storage/async-storage';
import { Platform } from 'react-native';
import Storage from 'react-native-storage';
import { isBrowser } from "../functions/is-browser";
import { logger } from "./logger";
const ONE_DAY = 1000 * 60 * 60 * 24;
const initStorage = () => {
  var _window;
  const backend = Platform.OS === 'web' ? isBrowser() ? // web
  (_window = window) === null || _window === void 0 ? void 0 : _window.localStorage :
  // static rendering/SSR in expo 50+
  undefined :
  // non-web (iOS/Android)
  AsyncStorage;
  const storage = new Storage({
    // maximum capacity, default 1000 key-ids
    size: 1000,
    // Use AsyncStorage for RN apps, or window.localStorage for web apps.
    // If storageBackend is not set, data will be lost after reload.
    storageBackend: backend,
    // expire time, default: 1 day (1000 * 3600 * 24 milliseconds).
    // can be null, which means never expire.
    defaultExpires: ONE_DAY * 30
  });
  return storage;
};
const storage = initStorage();
const getStorageName = name => `builderio.${name}`;

// stub, never called, but needed to fix bundling.
export const getCookieSync = _ => {};
export const getCookie = async ({
  name,
  canTrack
}) => {
  try {
    if (!canTrack) {
      return undefined;
    }

    // react-native does not support underscores in names
    const parsedName = name.replace(/_/g, '.');
    const data = await storage.load({
      key: getStorageName(parsedName)
    });
    return data.value;
  } catch (err) {
    if ((err === null || err === void 0 ? void 0 : err.name) !== 'NotFoundError') {
      logger.warn('[COOKIE] GET error: ', (err === null || err === void 0 ? void 0 : err.message) || err);
    }
    return undefined;
  }
};
export const setCookie = async ({
  name,
  value,
  expires,
  canTrack
}) => {
  try {
    if (!canTrack) {
      return undefined;
    }
    // convert `expires` date to number representing milliseconds from now until the date
    const expiresAsNumber = expires ? expires.getTime() - Date.now() : undefined;
    await storage.save({
      key: getStorageName(name),
      data: {
        value
      },
      expires: expiresAsNumber
    });
  } catch (err) {
    if ((err === null || err === void 0 ? void 0 : err.name) !== 'NotFoundError') {
      logger.warn('[COOKIE] SET error: ', (err === null || err === void 0 ? void 0 : err.message) || err);
    }
    return undefined;
  }
};
//# sourceMappingURL=cookie.js.map