"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _react = _interopRequireWildcard(require("react"));
var React = _react;
var _reactNative = require("react-native");
var _builderRegisteredComponents = require("../../constants/builder-registered-components");
var _target = require("../../constants/target");
var _components = _interopRequireDefault(require("../../context/components.context"));
var _evaluate = require("../../functions/evaluate/evaluate");
var _registerComponent = require("../../functions/register-component");
var _logger = require("../../helpers/logger");
var _blocks = _interopRequireDefault(require("../blocks/blocks"));
var _helpers = require("../content-variants/helpers");
var _inlinedScript = _interopRequireDefault(require("../inlined-script"));
var _enableEditor = _interopRequireDefault(require("./components/enable-editor"));
var _styles = _interopRequireDefault(require("./components/styles"));
var _content = require("./content.helpers");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && Object.prototype.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
function ContentComponent(props) {
  var _builderContextSignal2, _builderContextSignal3, _builderContextSignal4, _builderContextSignal5;
  const [scriptStr, setScriptStr] = (0, _react.useState)(() => {
    var _props$content, _props$content2;
    return (0, _helpers.getUpdateVariantVisibilityScript)({
      // eslint-disable-next-line @typescript-eslint/no-non-null-assertion, @typescript-eslint/no-non-null-asserted-optional-chain
      variationId: (_props$content = props.content) === null || _props$content === void 0 ? void 0 : _props$content.testVariationId,
      // eslint-disable-next-line @typescript-eslint/no-non-null-assertion, @typescript-eslint/no-non-null-asserted-optional-chain
      contentId: (_props$content2 = props.content) === null || _props$content2 === void 0 ? void 0 : _props$content2.id
    });
  });
  function contentSetState(newRootState) {
    setBuilderContextSignal(PREVIOUS_VALUE => ({
      ...PREVIOUS_VALUE,
      rootState: newRootState
    }));
  }
  const [registeredComponents, setRegisteredComponents] = (0, _react.useState)(() => [...(0, _builderRegisteredComponents.getDefaultRegisteredComponents)(), ...(props.customComponents || [])].reduce((acc, {
    component,
    ...info
  }) => ({
    ...acc,
    [info.name]: {
      component: component,
      ...(0, _registerComponent.serializeIncludingFunctions)(info)
    }
  }), {}));
  const [builderContextSignal, setBuilderContextSignal] = (0, _react.useState)(() => ({
    strictStyleMode: props.strictStyleMode,
    content: (0, _content.getContentInitialValue)({
      content: props.content,
      data: props.data
    }),
    localState: undefined,
    rootState: (0, _content.getRootStateInitialValue)({
      content: props.content,
      data: props.data,
      locale: props.locale
    }),
    rootSetState: contentSetState,
    context: props.context || {},
    canTrack: props.canTrack,
    apiKey: props.apiKey,
    apiVersion: props.apiVersion,
    componentInfos: [...(0, _builderRegisteredComponents.getDefaultRegisteredComponents)(), ...(props.customComponents || [])].reduce((acc, {
      component: _,
      ...info
    }) => ({
      ...acc,
      [info.name]: (0, _registerComponent.serializeIncludingFunctions)(info)
    }), {}),
    inheritedStyles: {},
    BlocksWrapper: props.blocksWrapper || _reactNative.ScrollView,
    BlocksWrapperProps: props.blocksWrapperProps || {},
    nonce: props.nonce || "",
    model: props.model
  }));
  const hasInitialized = (0, _react.useRef)(false);
  if (!hasInitialized.current) {
    var _builderContextSignal;
    if (!props.apiKey) {
      _logger.logger.error("No API key provided to `Content` component. This can cause issues. Please provide an API key using the `apiKey` prop.");
    }

    // run any dynamic JS code attached to content
    const jsCode = (_builderContextSignal = builderContextSignal.content) === null || _builderContextSignal === void 0 || (_builderContextSignal = _builderContextSignal.data) === null || _builderContextSignal === void 0 ? void 0 : _builderContextSignal.jsCode;
    if (jsCode) {
      (0, _evaluate.evaluate)({
        code: jsCode,
        context: props.context || {},
        localState: undefined,
        rootState: builderContextSignal.rootState,
        rootSetState: newState => {
          setBuilderContextSignal(PREVIOUS_VALUE => ({
            ...PREVIOUS_VALUE,
            rootState: newState
          }));
        },
        isExpression: false
      });
    }
    hasInitialized.current = true;
  }
  return /*#__PURE__*/React.createElement(_components.default.Provider, {
    value: {
      registeredComponents: registeredComponents
    }
  }, /*#__PURE__*/React.createElement(_enableEditor.default, {
    apiHost: props.apiHost,
    nonce: props.nonce,
    content: props.content,
    data: props.data,
    model: props.model,
    context: props.context,
    apiKey: props.apiKey,
    canTrack: props.canTrack,
    locale: props.locale,
    enrich: props.enrich,
    showContent: props.showContent,
    builderContextSignal: builderContextSignal,
    contentWrapper: props.contentWrapper,
    contentWrapperProps: props.contentWrapperProps,
    trustedHosts: props.trustedHosts,
    isNestedRender: props.isNestedRender,
    // eslint-disable-next-line object-shorthand
    setBuilderContextSignal: setBuilderContextSignal,
    // eslint-disable-next-line @typescript-eslint/ban-ts-comment
    // @ts-ignore
    strictStyleMode: props.strictStyleMode
  }, props.isSsrAbTest ? /*#__PURE__*/React.createElement(_inlinedScript.default, {
    id: "builderio-variant-visibility",
    scriptStr: scriptStr,
    nonce: props.nonce || ""
  }) : null, _target.TARGET !== "reactNative" ? /*#__PURE__*/React.createElement(_styles.default, {
    nonce: props.nonce || "",
    isNestedRender: props.isNestedRender,
    contentId: (_builderContextSignal2 = builderContextSignal.content) === null || _builderContextSignal2 === void 0 ? void 0 : _builderContextSignal2.id,
    cssCode: (_builderContextSignal3 = builderContextSignal.content) === null || _builderContextSignal3 === void 0 || (_builderContextSignal3 = _builderContextSignal3.data) === null || _builderContextSignal3 === void 0 ? void 0 : _builderContextSignal3.cssCode,
    customFonts: (_builderContextSignal4 = builderContextSignal.content) === null || _builderContextSignal4 === void 0 || (_builderContextSignal4 = _builderContextSignal4.data) === null || _builderContextSignal4 === void 0 ? void 0 : _builderContextSignal4.customFonts
  }) : null, /*#__PURE__*/React.createElement(_blocks.default, {
    blocks: (_builderContextSignal5 = builderContextSignal.content) === null || _builderContextSignal5 === void 0 || (_builderContextSignal5 = _builderContextSignal5.data) === null || _builderContextSignal5 === void 0 ? void 0 : _builderContextSignal5.blocks,
    context: builderContextSignal,
    registeredComponents: registeredComponents,
    linkComponent: props.linkComponent
  })));
}
var _default = exports.default = ContentComponent;
//# sourceMappingURL=content.js.map