"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.runInEdge = void 0;
var _helpers = require("../helpers");
var _acornInterpreter = _interopRequireDefault(require("./acorn-interpreter"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
/**
 * https://stackoverflow.com/a/46503625
 */
function patchInterpreter() {
  const originalGetProperty = _acornInterpreter.default.prototype.getProperty;
  const originalSetProperty = _acornInterpreter.default.prototype.setProperty;
  function newGetProperty(obj, name) {
    if (obj == null || !obj._connected) {
      return originalGetProperty.call(this, obj, name);
    }
    const value = obj._connected[name];
    if (Array.isArray(value)) {
      return this.nativeToPseudo(value);
    }
    if (typeof value === 'object') {
      // if the value is an object itself, create another connected object
      return this.createConnectedObject(value);
    }
    return value;
  }
  function newSetProperty(obj, name, value, opt_descriptor) {
    if (obj == null || !obj._connected) {
      return originalSetProperty.call(this, obj, name, value, opt_descriptor);
    }
    obj._connected[name] = this.pseudoToNative(value);
  }
  const getKeys = [];
  const setKeys = [];
  for (const key of Object.keys(_acornInterpreter.default.prototype)) {
    if (_acornInterpreter.default.prototype[key] === originalGetProperty) {
      getKeys.push(key);
    }
    if (_acornInterpreter.default.prototype[key] === originalSetProperty) {
      setKeys.push(key);
    }
  }
  for (const key of getKeys) {
    _acornInterpreter.default.prototype[key] = newGetProperty;
  }
  for (const key of setKeys) {
    _acornInterpreter.default.prototype[key] = newSetProperty;
  }
  _acornInterpreter.default.prototype.createConnectedObject = function (obj) {
    const connectedObject = this.createObject(this.OBJECT);
    connectedObject._connected = obj;
    return connectedObject;
  };
}
patchInterpreter();
const processCode = code => {
  return code
  // strip async/await polyfill: remove anything before 'function main()'
  .replace(/^.*?function main\(\)/, `
var __awaiter = function (e, t, n, r) {return r()},
__generator = function (e, t) { return t() };
function main()`)
  // replace ?. with .
  .replace(/\?\./g, '.');
};
const getJSONValName = val => val + 'JSON';
const runInEdge = ({
  builder,
  context,
  event,
  rootState,
  localState,
  rootSetState,
  code
}) => {
  const state = (0, _helpers.flattenState)({
    rootState,
    localState,
    rootSetState
  });
  const properties = (0, _helpers.getFunctionArguments)({
    builder,
    context,
    event,
    state
  });

  /**
   * Deserialize all properties from JSON strings to JS objects
   */
  const prependedCode = properties.map(([key]) => {
    const jsonValName = getJSONValName(key);
    if (key === 'state') {
      return ``;
    }
    return `var ${key} = ${jsonValName} === undefined ? undefined : JSON.parse(${jsonValName});`;
  }).join('\n');
  const cleanedCode = processCode(code);
  if (cleanedCode === '') return;
  const transformed = `
function theFunction() {
  ${prependedCode}

  ${cleanedCode}
}
theFunction();
`;
  const initFunc = function (interpreter, globalObject) {
    /**
     * serialize all function args to JSON strings
     */
    properties.forEach(([key, val]) => {
      if (key === 'state') {
        interpreter.setProperty(globalObject, key, interpreter.createConnectedObject(val), interpreter.READONLY_DESCRIPTOR);
      } else {
        const jsonVal = JSON.stringify(val);
        interpreter.setProperty(globalObject, getJSONValName(key), jsonVal);
      }
    });
  };
  const myInterpreter = new _acornInterpreter.default(transformed, initFunc);
  myInterpreter.run();
  const output = myInterpreter.pseudoToNative(myInterpreter.value);
  return output;
};
exports.runInEdge = runInEdge;
//# sourceMappingURL=edge-runtime.js.map