"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.USER_ATTRIBUTES_COOKIE_NAME = void 0;
exports.createUserAttributesService = createUserAttributesService;
exports.userAttributesService = exports.setClientUserAttributes = void 0;
var _target = require("../constants/target");
var _isBrowser = require("../functions/is-browser");
var _cookie = require("./cookie");
var _noSerializeWrapper = require("./no-serialize-wrapper");
const USER_ATTRIBUTES_COOKIE_NAME = exports.USER_ATTRIBUTES_COOKIE_NAME = 'builder.userAttributes';
function createUserAttributesService() {
  let canTrack = true;
  const subscribers = new Set();
  return {
    setUserAttributes(newAttrs) {
      if (!(0, _isBrowser.isBrowser)()) {
        return;
      }
      const userAttributes = {
        ...this.getUserAttributes(),
        ...newAttrs
      };
      (0, _cookie.setCookie)({
        name: USER_ATTRIBUTES_COOKIE_NAME,
        value: JSON.stringify(userAttributes),
        canTrack
      });
      subscribers.forEach(callback => callback(userAttributes));
    },
    getUserAttributes() {
      if (!(0, _isBrowser.isBrowser)()) {
        return {};
      }
      return JSON.parse((0, _cookie.getCookieSync)({
        name: USER_ATTRIBUTES_COOKIE_NAME,
        canTrack
      }) || '{}');
    },
    subscribeOnUserAttributesChange(callback, {
      fireImmediately
    } = {}) {
      subscribers.add(callback);
      if (fireImmediately) {
        callback(this.getUserAttributes());
      }
      return (0, _noSerializeWrapper.noSerializeWrapper)(function () {
        subscribers.delete(callback);
      });
    },
    setCanTrack(value) {
      canTrack = value;
    }
  };
}
let _userAttributesService;
if ((0, _isBrowser.isBrowser)() && _target.TARGET === 'qwik') {
  if (!window.__BUILDER_USER_ATTRIBUTES_SERVICE__) {
    window.__BUILDER_USER_ATTRIBUTES_SERVICE__ = createUserAttributesService();
  }
  _userAttributesService = window.__BUILDER_USER_ATTRIBUTES_SERVICE__;
} else {
  _userAttributesService = createUserAttributesService();
}
const userAttributesService = exports.userAttributesService = _userAttributesService;
const setClientUserAttributes = attributes => {
  userAttributesService.setUserAttributes(attributes);
};
exports.setClientUserAttributes = setClientUserAttributes;
//# sourceMappingURL=user-attributes.js.map