import * as React from "react";
import {
  FlatList,
  ScrollView,
  View,
  StyleSheet,
  Image,
  Text,
  Pressable,
  TextInput,
  TouchableOpacity,
  Button,
  Linking,
} from "react-native";

/**
 * This import is used by the Svelte SDK. Do not remove.
 */

export interface ImgProps {
  attributes?: any;
  imgSrc?: string; // TODO(misko): I think this is unused
  image?: string;
  altText?: string;
  backgroundSize?: "cover" | "contain";
  backgroundPosition?:
    | "center"
    | "top"
    | "left"
    | "right"
    | "bottom"
    | "top left"
    | "top right"
    | "bottom left"
    | "bottom right";
}

import { isEditing } from "../../functions/is-editing";
import { filterAttrs } from "../helpers";
import { getSrcSet } from "../image/image.helpers";
import { setAttrs } from "../helpers";

function ImgComponent(props: ImgProps) {
  function srcSetToUse() {
    const url = props.imgSrc || props.image;
    if (!url || typeof url !== "string") {
      return undefined;
    }

    // We can auto add srcset for cdn.builder.io images
    if (!url.match(/builder\.io/)) {
      return undefined;
    }
    return getSrcSet(url);
  }

  return (
    <Image
      loading="lazy"
      style={{
        objectFit: props.backgroundSize || "cover",
        objectPosition: props.backgroundPosition || "center",
      }}
      key={(isEditing() && props.imgSrc) || "default-key"}
      alt={props.altText}
      source={{ uri: props.imgSrc || props.image }}
      srcSet={srcSetToUse()}
      {...{}}
      {...props.attributes}
    />
  );
}

export default ImgComponent;
